@@ -51,12 +51,24 @@ class CEMBASnmCAndSnm3C(AutoPathMixIn):
         self.CEMBA_SNM3C_25K_IMPUTED_COOL_PATH = CEMBA_SNM3C_25K_IMPUTED_COOL_PATH
         self.CEMBA_SNM3C_100K_IMPUTED_COOL_PATH = CEMBA_SNM3C_100K_IMPUTED_COOL_PATH
 
+        # CoolDS snm3C multi-sample zarr dataset
+        self.CEMBA_SNM3C_L4REGION_COOL_DS_PATH_LIST = CEMBA_SNM3C_L4REGION_COOL_DS_PATH_LIST
+        self.CEMBA_SNM3C_L4REGION_COOL_DS_SAMPLE_WEIGHTS_PATH = CEMBA_SNM3C_L4REGION_COOL_DS_SAMPLE_WEIGHTS_PATH
+        self.CEMBA_SNM3C_L4REGION_COOL_DS_CHROMS_SIZES_PATH = CEMBA_SNM3C_L4REGION_COOL_DS_CHROMS_SIZES_PATH
+
         # dataset paths
         self.CEMBA_SNMC_MCDS_PATH = CEMBA_SNMC_MCDS_PATH
         self.CEMBA_SNM3C_MCDS_PATH = CEMBA_SNM3C_MCDS_PATH
+
+        # CEMBA snm3C chromatin conformation matrix paths
         self.CEMBA_SNM3C_3C_CHROM100K_RAW_ZARR_PATH = CEMBA_SNM3C_3C_CHROM100K_RAW_ZARR_PATH
         self.CEMBA_SNM3C_3C_COMPARTMENT_ZARR_PATH = CEMBA_SNM3C_3C_COMPARTMENT_ZARR_PATH
         self.CEMBA_SNM3C_3C_DOMAIN_INSULATION_ZARR_PATH = CEMBA_SNM3C_3C_DOMAIN_INSULATION_ZARR_PATH
+        self.CEMBA_SNM3C_LOOP_ANOVA_DS_PATH = CEMBA_SNM3C_LOOP_ANOVA_DS_PATH
+        self.CEMBA_SNM3C_LOOP_AND_SUMMIT_DS_PATH = CEMBA_SNM3C_LOOP_AND_SUMMIT_DS_PATH
+        self.CEMBA_SNM3C_LOOP_VALUES_DS_PATH = CEMBA_SNM3C_LOOP_VALUES_DS_PATH
+        self.CEMBA_SNM3C_DOMAIN_BOUNDARY_AND_CHI2_DS_PAT = CEMBA_SNM3C_DOMAIN_BOUNDARY_AND_CHI2_DS_PATH
+        self.CEMBA_SNM3C_DOMAIN_INSULATION_SCORE_DS_PATH = CEMBA_SNM3C_DOMAIN_INSULATION_SCORE_DS_PATH
 
         # other metadata
         self.CEMBA_LIU_2021_NATURE_SNMC_METADATA_PATH = CEMBA_LIU_2021_NATURE_SNMC_METADATA_PATH
@@ -323,9 +335,6 @@ class CEMBASnmCAndSnm3C(AutoPathMixIn):
     def get_mc_annot(self):
         annot = CEMBAmCCellAnnotation(self.CEMBA_SNMC_CELL_TYPE_ANNOTATION_PATH,
                                       self.get_mc_mapping_metric())
-
-        # mC L4 Annot also created from AIBS TENX Annot V2
-        annot.add_palette(palette=PALETTES['AIBS.TENX.Annot.V2'], da_name='L4_annot')
         return annot
 
     def get_m3c_annot(self):
@@ -348,6 +357,7 @@ class CEMBASnmCAndSnm3C(AutoPathMixIn):
         ).to_pandas()
         return gene_data
 
+    @lru_cache(maxsize=200)
     def _get_cluster_gene_frac(self, dataset, gene, mc_type, value_type, alpha, norm_frac):
         if dataset == 'mc':
             if self._mc_cluster_gene_ds is None:
@@ -510,3 +520,16 @@ class CEMBASnmCAndSnm3C(AutoPathMixIn):
     def get_cell_type_palette(self):
         p = pd.read_csv(self.CEMBA_CELL_TYPE_ANNOT_PALETTE_PATH, index_col=0, header=None).squeeze().to_dict()
         return p
+
+    def get_cool_ds(self):
+        from ALLCools.mcds.cool_ds import CoolDS
+        sample_weights = pd.read_csv(
+            self.CEMBA_SNM3C_L4REGION_COOL_DS_SAMPLE_WEIGHTS_PATH, index_col=0
+        ).squeeze()
+        cool_ds = CoolDS(
+            cool_ds_paths=self.CEMBA_SNM3C_L4REGION_COOL_DS_PATH_LIST,
+            chrom_sizes_path=self.CEMBA_SNM3C_L4REGION_COOL_DS_CHROMS_SIZES_PATH,
+            sample_weights=sample_weights,
+            sample_dim='sample_id'
+        )
+        return cool_ds
